@@ -1,8 +1,8 @@
 // -*- c++ -*-
 //
-// $Id: bdbuffer.h 2719 2009-08-20 01:30:25Z rafi $
+// $Id: bdbuffer.h 5579 2013-11-20 20:54:28Z rafisol $
 //
-// Copyright (C) 2008, 2009  Rafael Ostertag
+// Copyright (C) 2008-2010  Rafael Ostertag
 //
 // This file is part of YAPET.
 //
@@ -31,23 +31,19 @@
 //
 
 #ifndef _BDBUFFER_H
-#define _BDBUFFER_H
+#define _BDBUFFER_H 1
 
 #ifdef HAVE_CONFIG_H
-#include <config.h>
+#include "config.h"
 #endif
 
 #ifdef HAVE_INTTYPES_H
-# include <inttypes.h>
+#include <inttypes.h>
 #endif
 
-#ifdef HAVE_STDLIB_h
-# include <stdlib.h>
-#endif
+#include <cstdlib>
+#include <stdexcept>
 
-#ifdef HAVE_STDEXCEPT
-# include <stdexcept>
-#endif
 
 #include "yapetexception.h"
 
