@@ -1,8 +1,8 @@
 // -*- c++ -*-
 //
-// $Id: crypt.h 2850 2009-09-01 10:53:25Z rafi $
+// $Id: crypt.h 5644 2013-11-23 08:36:06Z rafisol $
 //
-// Copyright (C) 2008, 2009  Rafael Ostertag
+// Copyright (C) 2008-2010  Rafael Ostertag
 //
 // This file is part of YAPET.
 //
@@ -31,17 +31,17 @@
 //
 
 #ifndef _CRYPT_H
-#define _CRYPT_H
+#define _CRYPT_H 1
 
 #ifdef HAVE_CONFIG_H
-# include <config.h>
+# include "config.h"
 #endif
 
 #ifdef HAVE_INTTYPES_H
 # include <inttypes.h>
 #endif
 
-#include "../intl.h"
+#include "intl.h"
 
 
 #include <openssl/evp.h>
@@ -163,7 +163,7 @@ namespace YAPET {
                 EVP_CIPHER_CTX_init (&ctx);
                 int retval = EVP_EncryptInit_ex (&ctx,
                                                  cipher,
-                                                 NULL,
+                                                 0,
                                                  key,
                                                  key.getIVec() );
 
@@ -241,7 +241,7 @@ namespace YAPET {
                 EVP_CIPHER_CTX_init (&ctx);
                 int retval = EVP_DecryptInit_ex (&ctx,
                                                  cipher,
-                                                 NULL,
+                                                 0,
                                                  key,
                                                  key.getIVec() );
 
@@ -284,12 +284,12 @@ namespace YAPET {
 
                 decdata->resize (outlen + tmplen);
                 EVP_CIPHER_CTX_cleanup (&ctx);
-		Record<T>* r = NULL;
+		Record<T>* r = 0;
 		try {
 		    r = new Record<T>;
 		    *r = *decdata;
 		} catch (...) {
-		    if ( r != NULL)
+		    if ( r != 0)
 			delete r;
 		    delete decdata;
 		    throw;
