@@ -1,6 +1,6 @@
-// $Id: file.cc 3351 2010-09-17 21:55:30Z java $
+// $Id: file.cc 5906 2014-01-26 12:44:06Z rafisol $
 //
-// Copyright (C) 2008-2010  Rafael Ostertag
+// Copyright (C) 2008-2011, 2013  Rafael Ostertag
 //
 // This file is part of YAPET.
 //
@@ -28,12 +28,14 @@
 // well as that of the covered work.
 //
 
-#include "../intl.h"
+#include "intl.h"
 #include "crypt.h"
 #include "record.h"
 #include "structs.h"
 #include "file.h"
 
+#include <unistd.h>
+
 #ifdef TIME_WITH_SYS_TIME
 # include <sys/time.h>
 # include <time.h>
@@ -49,34 +51,22 @@
 # include <inttypes.h>
 #endif
 
-#ifdef HAVE_SYS_TYPES_H
-# include <sys/types.h>
-#endif
+#include <sys/types.h>
 
-#ifdef HAVE_SYS_STAT_H
-# include <sys/stat.h>
-#endif
+#include <sys/stat.h>
 
 #ifdef HAVE_FCNTL_H
 # include <fcntl.h>
 #endif
 
-#ifdef HAVE_STRING_H
-# include <string.h>
-#endif
-
-#ifdef HAVE_ERRNO_H
-# include <errno.h>
-#endif
-
-#ifdef HAVE_UNISTD_H
-# include <unistd.h>
-#endif
-
 #ifdef HAVE_ALLOCA_H
 # include <alloca.h>
 #endif
 
+#include <cstring>
+#include <cerrno>
+
+
 using namespace YAPET;
 
 /**
@@ -109,12 +99,11 @@ const char RECOG_STR[] = "YAPET1.0";
  */
 void
 File::checkFileSecurity() throw (YAPETException) {
-#if defined(HAVE_FSTAT) && defined(HAVE_GETUID)
     struct stat buf;
     int err = fstat (fd, &buf);
 
     if (err == -1)
-        throw YAPETException (strerror (errno) );
+        throw YAPETException (std::strerror (errno) );
 
     uid_t uid = getuid();
 
@@ -128,8 +117,6 @@ File::checkFileSecurity() throw (YAPETException) {
         std::string tmp2 (_ (" not secure.") );
         throw YAPETRetryException (tmp1 + filename + tmp2);
     }
-
-#endif
 }
 
 /**
@@ -141,12 +128,11 @@ File::checkFileSecurity() throw (YAPETException) {
  */
 void
 File::setFileSecurity() throw (YAPETException) {
-#if defined(HAVE_FCHOWN) && defined(HAVE_FCHMOD) && defined(HAVE_FSTAT)
     struct stat buf;
     int err = fstat (fd, &buf);
 
     if (err == -1)
-        throw YAPETException (strerror (errno) );
+        throw YAPETException (std::strerror (errno) );
 
     err = fchown (fd, getuid(), buf.st_gid);
 
@@ -161,8 +147,6 @@ File::setFileSecurity() throw (YAPETException) {
         std::string tmp (_ ("Cannot set file permissions on ") );
         throw YAPETRetryException (tmp + filename);
     }
-
-#endif
 }
 
 
@@ -179,7 +163,9 @@ File::openCreate() throw (YAPETException) {
                   S_IRUSR | S_IWUSR | S_IRGRP | S_IROTH ) );
 
     if (fd == -1)
-        throw YAPETException (strerror (errno) );
+        throw YAPETException (std::strerror (errno) );
+
+    mtime = lastModified();
 
     if (usefsecurity)
         checkFileSecurity();
@@ -194,7 +180,9 @@ File::openNoCreate() throw (YAPETException) {
     fd = ::open (filename.c_str(), O_RDWR | O_APPEND);
 
     if (fd == -1)
-        throw YAPETException (strerror (errno) );
+        throw YAPETException (std::strerror (errno) );
+
+    mtime = lastModified();
 
     if (usefsecurity)
         checkFileSecurity();
@@ -212,7 +200,7 @@ File::lastModified() const throw (YAPETException) {
     int retval = fstat (fd, &st_buf);
 
     if (retval == -1)
-        throw YAPETException (strerror (errno) );
+        throw YAPETException (std::strerror (errno) );
 
     return st_buf.st_mtime;
 }
@@ -229,7 +217,7 @@ File::seekCurr (off_t offset) const throw (YAPETException) {
     off_t pos = lseek (fd, offset, SEEK_CUR);
 
     if ( ( (off_t) - 1) == pos)
-        throw YAPETException (strerror (errno) );
+        throw YAPETException (std::strerror (errno) );
 }
 
 /**
@@ -242,7 +230,7 @@ File::seekAbs (off_t offset) const throw (YAPETException) {
     off_t pos = lseek (fd, offset, SEEK_SET);
 
     if ( ( (off_t) - 1) == pos)
-        throw YAPETException (strerror (errno) );
+        throw YAPETException (std::strerror (errno) );
 
     if (pos != offset)
         throw YAPETException (_ ("Error seeking within file: ") + filename);
@@ -261,7 +249,7 @@ File::preparePWSave() throw (YAPETException) {
     try {
         openCreate();
     } catch (YAPETException& ex) {
-        if (curr_header != NULL)
+        if (curr_header != 0)
             delete curr_header;
 
         throw;
@@ -279,12 +267,12 @@ File::preparePWSave() throw (YAPETException) {
  */
 void
 File::seekDataSection() const throw (YAPETException) {
-    seekAbs (strlen (RECOG_STR) );
+    seekAbs (std::strlen (RECOG_STR) );
     uint32_t len;
     int retval = ::read (fd, &len, sizeof (uint32_t) );
 
     if (retval == -1)
-        throw YAPETException (strerror (errno) );
+        throw YAPETException (std::strerror (errno) );
 
     if ( ( (size_t) retval) != sizeof (uint32_t) )
         throw YAPETException (_ ("Unable to seek to data section") );
@@ -307,7 +295,7 @@ File::seekDataSection() const throw (YAPETException) {
  *
  * @return a pointer to a \c BDBuffer holding the encrypted password
  * record. The memory occupied by the buffer has to be freed by the
- * caller of the method. It returns \c NULL when the end of file has
+ * caller of the method. It returns \c 0 when the end of file has
  * been reached.
  */
 BDBuffer*
@@ -316,10 +304,10 @@ File::read() const throw (YAPETException) {
     int retval = ::read (fd, &len, sizeof (uint32_t) );
 
     if (retval == -1)
-        throw YAPETException (strerror (errno) );
+        throw YAPETException (std::strerror (errno) );
 
     if (retval == 0)
-        return NULL;
+        return 0;
 
     if ( ( (size_t) retval) < sizeof (uint32_t) )
         throw YAPETException (_ ("Short read on file: ") + filename);
@@ -330,11 +318,11 @@ File::read() const throw (YAPETException) {
     retval = ::read (fd, *buf, len);
 
     if (retval == -1)
-        throw YAPETException (strerror (errno) );
+        throw YAPETException (std::strerror (errno) );
 
     if (retval == 0) {
         delete buf;
-        return NULL;
+        return 0;
     }
 
     if ( ( (uint32_t) retval) < len) {
@@ -355,29 +343,15 @@ File::read() const throw (YAPETException) {
  * @param forceappend if this flag is set to \c true, the method first
  * seeks to the end of the file, if set to \c false, it writes at the
  * position the file pointer points to.
- *
- * @param forcewrite before writing any data, the method checks
- * whether the last modification date stored in \c mtime matches the
- * date returned by \c lastModified(). If they differ, and this flag
- * is set to \c false, the write operation will fail and an exception
- * is thrown. If the flag is set to \c true, it writes the data to the
- * file regardless of the last modification date.
- *
- * @throw YAPETRetryException if the file has been externally modified
- * (outside of this class), and \c forcewrite is not \c true, this
- * exception is thrown.
  */
 void
-File::write (const BDBuffer& buff, bool forceappend, bool forcewrite)
-throw (YAPETException, YAPETRetryException) {
-    if ( (mtime != lastModified() ) && !forcewrite)
-        throw YAPETRetryException (_ ("File has been modified") );
-
+File::write (const BDBuffer& buff, bool forceappend)
+throw (YAPETException) {
     if (forceappend) {
         off_t pos = lseek (fd, 0, SEEK_END);
 
         if ( ( (off_t) - 1) == pos)
-            throw YAPETException (strerror (errno) );
+            throw YAPETException (std::strerror (errno) );
     }
 
     uint32_t s = buff.size();
@@ -386,7 +360,7 @@ throw (YAPETException, YAPETRetryException) {
     int retval = ::write (fd, &s, sizeof (uint32_t) );
 
     if (retval == -1)
-        throw YAPETException (strerror (errno) );
+        throw YAPETException (std::strerror (errno) );
 
     if (retval != sizeof (uint32_t) )
         throw YAPETException (_ ("Short write on file: ") + filename);
@@ -394,7 +368,7 @@ throw (YAPETException, YAPETRetryException) {
     retval = ::write (fd, buff, buff.size() );
 
     if (retval == -1)
-        throw YAPETException (strerror (errno) );
+        throw YAPETException (std::strerror (errno) );
 
     if ( ( (size_t) retval) < buff.size() )
         throw YAPETException (_ ("Short write on file: ") + filename);
@@ -413,7 +387,7 @@ File::isempty() const throw (YAPETException) {
     int retval = fstat (fd, &st_buf);
 
     if (retval == -1)
-        throw YAPETException (strerror (errno) );
+        throw YAPETException (std::strerror (errno) );
 
     if (st_buf.st_size == 0)
         return true;
@@ -435,19 +409,19 @@ File::initFile (const Key& key) throw (YAPETException) {
     Record<FileHeader_64> header;
     FileHeader_64* ptr = header;
     ptr->version = VERSION_2;
-    memcpy (ptr->control, CONTROL_STR, HEADER_CONTROL_SIZE);
-    ptr->pwset = int_to_disk<int64_t> (time (NULL) );
+    std::memcpy (ptr->control, CONTROL_STR, HEADER_CONTROL_SIZE);
+    ptr->pwset = int_to_disk<int64_t> (time (0) );
     mtime = lastModified();
     writeHeader (header, key);
     // Sanity checks
     BDBuffer* buff = readHeader();
 
-    if (buff == NULL)
+    if (buff == 0)
         throw YAPETException (_ ("EOF encountered while reading header") );
 
     Record<FileHeader_64>* dec_hdr = crypt.decrypt<FileHeader_64> (*buff);
     FileHeader_64* ptr_dec_hdr = *dec_hdr;
-    int retval = memcmp (ptr_dec_hdr->control, ptr->control, HEADER_CONTROL_SIZE);
+    int retval = std::memcmp (ptr_dec_hdr->control, ptr->control, HEADER_CONTROL_SIZE);
 
     if (retval != 0)
         throw YAPETException (_ ("Sanity check for control field failed") );
@@ -472,18 +446,18 @@ void
 File::writeHeader (const Record<FileHeader_64>& header, const Key& key)
 throw (YAPETException) {
     Crypt crypt (key);
-    BDBuffer* buff = NULL;
+    BDBuffer* buff = 0;
 
     try {
         buff = crypt.encrypt (header);
         writeHeader (*buff);
     } catch (YAPETException& ex) {
-        if (buff != NULL)
+        if (buff != 0)
             delete buff;
 
         throw;
     } catch (...) {
-        if (buff != NULL)
+        if (buff != 0)
             delete buff;
 
         throw YAPETException (_ ("Unknown exception catched") );
@@ -503,12 +477,12 @@ void
 File::writeHeader (const BDBuffer& enc_header) throw (YAPETException) {
     seekAbs (0);
     // Write the recognition string
-    ssize_t retval = ::write (fd, RECOG_STR, strlen (RECOG_STR) );
+    ssize_t retval = ::write (fd, RECOG_STR, std::strlen (RECOG_STR) );
 
     if (retval == -1)
-        throw YAPETException (strerror (errno) );
+        throw YAPETException (std::strerror (errno) );
 
-    if ( ( (size_t) retval) != strlen (RECOG_STR) )
+    if ( ( (size_t) retval) != std::strlen (RECOG_STR) )
         throw YAPETException (_ ("Short write on file: ") + filename);
 
     mtime = lastModified();
@@ -530,20 +504,20 @@ File::writeHeader (const BDBuffer& enc_header) throw (YAPETException) {
 BDBuffer*
 File::readHeader() const throw (YAPETException) {
     seekAbs (0);
-    char* buff = (char*) alloca (strlen (RECOG_STR) );
+    char* buff = (char*) alloca (std::strlen (RECOG_STR) );
 
-    if (buff == NULL)
+    if (buff == 0)
         throw YAPETException (_ ("Memory exhausted") );
 
-    int retval = ::read (fd, buff, strlen (RECOG_STR) );
+    int retval = ::read (fd, buff, std::strlen (RECOG_STR) );
 
     if (retval == -1)
-        throw YAPETException (strerror (errno) );
+        throw YAPETException (std::strerror (errno) );
 
-    if ( ( (size_t) retval) != strlen (RECOG_STR) )
+    if ( ( (size_t) retval) != std::strlen (RECOG_STR) )
         throw YAPETException (_ ("File type not recognized") );
 
-    retval = memcmp (RECOG_STR, buff, strlen (RECOG_STR) );
+    retval = std::memcmp (RECOG_STR, buff, std::strlen (RECOG_STR) );
 
     if (retval != 0)
         throw YAPETException (_ ("File type not recognized") );
@@ -558,9 +532,9 @@ File::readHeader() const throw (YAPETException) {
  * returned for null values in order to determine which header to use, e.g.
  *
  @verbatim
- if (ptr32 != NULL) {
+ if (ptr32 != 0) {
     // do something
- } else if (ptr64 != NULL) {
+ } else if (ptr64 != 0) {
     // do something
  } else {
     // error
@@ -573,21 +547,21 @@ File::readHeader() const throw (YAPETException) {
  * @param key reference to a Key object used to decrypt the header.
  *
  * @param ptr32 the 32bit header record. If the yapet file does not contain a
- * FileHeader_32, NULL is returned.
+ * FileHeader_32, 0 is returned.
  *
  * @param ptr64 the 64bit header record. If the yapet file does not contain a
- * FileHeader_64, NULL is returned.
+ * FileHeader_64, 0 is returned.
  */
 void
 File::readHeader(const Key& key, Record<FileHeader_32>** ptr32, Record<FileHeader_64>** ptr64) const throw(YAPETException) {
-    assert(ptr32 != NULL && ptr64 != NULL);
-    if (ptr32 == NULL)
-	throw YAPETException(_("Null pointer passed in ptr32"), NULLPOINTER);
-    if (ptr64 == NULL)
-	throw YAPETException(_("Null pointer passed in ptr64"), NULLPOINTER);
+    assert(ptr32 != 0 && ptr64 != 0);
+    if (ptr32 == 0)
+	throw YAPETException(_("Null pointer passed in ptr32"), ZEROPOINTER);
+    if (ptr64 == 0)
+	throw YAPETException(_("Null pointer passed in ptr64"), ZEROPOINTER);
 
     Crypt crypt (key);
-    BDBuffer* enc_header = NULL;
+    BDBuffer* enc_header = 0;
 
     try {
         enc_header = readHeader();
@@ -596,61 +570,61 @@ File::readHeader(const Key& key, Record<FileHeader_32>** ptr32, Record<FileHeade
 	    *ptr32 = crypt.decrypt<FileHeader_32> (*enc_header);
 	} catch (YAPETException& ex) {
 
-	    if (*ptr32 != NULL) {
+	    if (*ptr32 != 0) {
 		delete *ptr32;
-		*ptr32 = NULL;
+		*ptr32 = 0;
 	    }
 
 	    try {
 		*ptr64 = crypt.decrypt<FileHeader_64> (*enc_header);
 	    } catch (YAPETEncryptionException& ex) { // Catch invalid password
-		if (enc_header != NULL) {
+		if (enc_header != 0) {
 		    delete enc_header;
-		    enc_header = NULL;
+		    enc_header = 0;
 		}
 		
-		if (*ptr32 != NULL) {
+		if (*ptr32 != 0) {
 		    delete *ptr32;
-		    *ptr32 = NULL;
+		    *ptr32 = 0;
 		}
-		if (*ptr64 != NULL) {
+		if (*ptr64 != 0) {
 		    delete *ptr64;
-		    *ptr64 = NULL;
+		    *ptr64 = 0;
 		}
 		
 		throw YAPETInvalidPasswordException();
 	    } catch (YAPETException &ex) {
 		// Ok, we got another problem
-		if (*ptr64 != NULL) {
+		if (*ptr64 != 0) {
 		    delete *ptr64;
-		    *ptr64 = NULL;
+		    *ptr64 = 0;
 		}
 		throw;
 	    }
 	}
     } catch (YAPETEncryptionException& ex) { // Catch invalid password
-        if (enc_header != NULL) delete enc_header;
+        if (enc_header != 0) delete enc_header;
 
-        if (*ptr32 != NULL) {
+        if (*ptr32 != 0) {
 	    delete *ptr32;
-	    *ptr32 = NULL;
+	    *ptr32 = 0;
 	}
-	if (*ptr64 != NULL) {
+	if (*ptr64 != 0) {
 	    delete *ptr64;
-	    *ptr64 = NULL;
+	    *ptr64 = 0;
 	}
 
         throw YAPETInvalidPasswordException();
     } catch (YAPETException& ex) {
-        if (enc_header != NULL) delete enc_header;
+        if (enc_header != 0) delete enc_header;
 
-        if (*ptr32 != NULL) {
+        if (*ptr32 != 0) {
 	    delete *ptr32;
-	    *ptr32 = NULL;
+	    *ptr32 = 0;
 	}
-	if (*ptr64 != NULL) {
+	if (*ptr64 != 0) {
 	    delete *ptr64;
-	    *ptr64 = NULL;
+	    *ptr64 = 0;
 	}
 
         throw;
@@ -676,31 +650,31 @@ void
 File::validateKey (const Key& key)
 throw (YAPETException, YAPETInvalidPasswordException) {
     // Expect either a 32bit or 64bit header
-    Record<FileHeader_32>* dec_header_32 = NULL;
-    Record<FileHeader_64>* dec_header_64 = NULL;
+    Record<FileHeader_32>* dec_header_32 = 0;
+    Record<FileHeader_64>* dec_header_64 = 0;
 
     readHeader(key, &dec_header_32, &dec_header_64);
-    assert(dec_header_32 != NULL || dec_header_64 != NULL);
+    assert(dec_header_32 != 0 || dec_header_64 != 0);
 
     FileHeader_32* ptr_dec_header_32 = 
-	(dec_header_32 != NULL) ? static_cast<FileHeader_32*>(*dec_header_32) : NULL;
+	(dec_header_32 != 0) ? static_cast<FileHeader_32*>(*dec_header_32) : 0;
     FileHeader_64* ptr_dec_header_64 = 
-	(dec_header_64 != NULL) ? static_cast<FileHeader_64*>(*dec_header_64) : NULL;
+	(dec_header_64 != 0) ? static_cast<FileHeader_64*>(*dec_header_64) : 0;
 
     int retval;
-    if (ptr_dec_header_32 != NULL) {
-	retval = memcmp (ptr_dec_header_32->control,
+    if (ptr_dec_header_32 != 0) {
+	retval = std::memcmp (ptr_dec_header_32->control,
                          CONTROL_STR,
                          HEADER_CONTROL_SIZE);
     } else {
-	assert(ptr_dec_header_64 != NULL);
-	retval = memcmp (ptr_dec_header_64->control,
+	assert(ptr_dec_header_64 != 0);
+	retval = std::memcmp (ptr_dec_header_64->control,
                          CONTROL_STR,
                          HEADER_CONTROL_SIZE);
     }
-    if (dec_header_32 != NULL)
+    if (dec_header_32 != 0)
 	delete dec_header_32;
-    if (dec_header_64 != NULL)
+    if (dec_header_64 != 0)
 	delete dec_header_64;
 
     if (retval != 0)
@@ -737,7 +711,7 @@ throw (YAPETException, YAPETInvalidPasswordException) {
  * read access.
  */
 File::File (const std::string& fn, const Key& key, bool create, bool secure)
-throw (YAPETException) : filename (fn), usefsecurity (secure) {
+    throw (YAPETException) : filename (fn), mtime(0), usefsecurity (secure) {
     if (create)
         openCreate();
     else
@@ -757,7 +731,7 @@ File::File (const File& f) throw (YAPETException) {
     fd = dup (f.fd);
 
     if (fd == -1)
-        throw YAPETException (strerror (errno) );
+        throw YAPETException (std::strerror (errno) );
 
     filename = f.filename;
     mtime = f.mtime;
@@ -776,19 +750,33 @@ File::~File() {
  *
  * @param records list of \c PartDec records
  *
+ * @param forcewrite before writing any data, the method checks
+ * whether the last modification date stored in \c mtime matches the
+ * date returned by \c lastModified(). If they differ, and this flag
+ * is set to \c false, the write operation will fail and an exception
+ * is thrown. If the flag is set to \c true, it writes the data to the
+ * file regardless of the last modification date.
+ *
+ * @throw YAPETRetryException if the file has been externally modified
+ * (outside of this class), and \c forcewrite is not \c true, this
+ * exception is thrown.
+ *
  * @sa PartDec
  */
 void
-File::save (std::list<PartDec>& records) throw (YAPETException) {
+File::save (const std::list<PartDec>& records, bool forcewrite) throw (YAPETException, YAPETRetryException) {
+    if ( (mtime != lastModified() ) && !forcewrite)
+        throw YAPETRetryException (_ ("File has been externally modified") );
+
     if (usefsecurity)
         setFileSecurity();
 
     preparePWSave();
-    std::list<PartDec>::iterator it = records.begin();
+    std::list<PartDec>::const_iterator it = records.begin();
 
     while (it != records.end() ) {
         write ( it->getEncRecord() );
-        it++;
+        ++it;
     }
 }
 
@@ -808,19 +796,19 @@ File::save (std::list<PartDec>& records) throw (YAPETException) {
 std::list<PartDec>
 File::read (const Key& key) const throw (YAPETException) {
     seekDataSection();
-    BDBuffer* buff = NULL;
+    BDBuffer* buff = 0;
     std::list<PartDec> retval;
 
     try {
         buff = read();
 
-        while (buff != NULL) {
+        while (buff != 0) {
             retval.push_back (PartDec (*buff, key) );
             delete buff;
             buff = read();
         }
     } catch (YAPETException& ex) {
-        if (buff != NULL)
+        if (buff != 0)
             delete buff;
 
         throw;
@@ -845,7 +833,11 @@ File::read (const Key& key) const throw (YAPETException) {
  */
 void
 File::setNewKey (const Key& oldkey,
-                 const Key& newkey) throw (YAPETException) {
+                 const Key& newkey,
+		 bool forcewrite) throw (YAPETException, YAPETRetryException) {
+    if ( (mtime != lastModified() ) && !forcewrite)
+        throw YAPETRetryException (_ ("File has been externally modified") );
+
     close (fd);
     std::string backupfilename (filename + ".bak");
     int retval = rename (filename.c_str(), backupfilename.c_str() );
@@ -853,10 +845,10 @@ File::setNewKey (const Key& oldkey,
     if (retval == -1) {
         // Reopen the old file
         openNoCreate();
-        throw YAPETException (strerror (errno) );
+        throw YAPETException (std::strerror (errno) );
     }
 
-    File* oldfile = NULL;
+    File* oldfile = 0;
 
     try {
         // Reopen the old (backup) file
@@ -871,8 +863,8 @@ File::setNewKey (const Key& oldkey,
         Crypt newcrypt (newkey);
 
         while (it != entries.end() ) {
-            Record<PasswordRecord>* dec_rec_ptr = NULL;
-            BDBuffer* new_enc_rec = NULL;
+            Record<PasswordRecord>* dec_rec_ptr = 0;
+            BDBuffer* new_enc_rec = 0;
 
             try {
                 // Decrypt with the old key
@@ -885,19 +877,19 @@ File::setNewKey (const Key& oldkey,
                 delete dec_rec_ptr;
                 delete new_enc_rec;
             } catch (YAPETException& ex) {
-                if (dec_rec_ptr != NULL)
+                if (dec_rec_ptr != 0)
                     delete dec_rec_ptr;
 
-                if (new_enc_rec != NULL)
+                if (new_enc_rec != 0)
                     delete new_enc_rec;
 
                 throw;
             }
 
-            it++;
+            ++it;
         }
     } catch (YAPETException& ex) {
-        if (oldfile != NULL)
+        if (oldfile != 0)
             delete oldfile;
 
         throw;
@@ -920,28 +912,28 @@ int64_t
 File::getMasterPWSet (const Key& key) const
 throw (YAPETException, YAPETInvalidPasswordException) {
     // Expect either a 32bit or 64bit header
-    Record<FileHeader_32>* dec_header_32 = NULL;
-    Record<FileHeader_64>* dec_header_64 = NULL;
+    Record<FileHeader_32>* dec_header_32 = 0;
+    Record<FileHeader_64>* dec_header_64 = 0;
 
     readHeader(key, &dec_header_32, &dec_header_64);
-    assert(dec_header_32 != NULL || dec_header_64 != NULL);
+    assert(dec_header_32 != 0 || dec_header_64 != 0);
 
     FileHeader_32* ptr_dec_header_32 = 
-	(dec_header_32 != NULL) ? static_cast<FileHeader_32*>(*dec_header_32) : NULL;
+	(dec_header_32 != 0) ? static_cast<FileHeader_32*>(*dec_header_32) : 0;
     FileHeader_64* ptr_dec_header_64 = 
-	(dec_header_64 != NULL) ? static_cast<FileHeader_64*>(*dec_header_64) : NULL;
+	(dec_header_64 != 0) ? static_cast<FileHeader_64*>(*dec_header_64) : 0;
 
     int64_t t;
-    if (ptr_dec_header_32 != NULL) {
+    if (ptr_dec_header_32 != 0) {
 	t = int_from_disk<int32_t> (ptr_dec_header_32->pwset);
     } else {
-	assert(ptr_dec_header_64 != NULL);
+	assert(ptr_dec_header_64 != 0);
 	t = int_from_disk<int64_t> (ptr_dec_header_64->pwset);
     }
 
-    if (dec_header_32 != NULL)
+    if (dec_header_32 != 0)
 	delete dec_header_32;
-    if (dec_header_64 != NULL)
+    if (dec_header_64 != 0)
 	delete dec_header_64;
 
     return t;
@@ -955,28 +947,28 @@ throw (YAPETException, YAPETInvalidPasswordException) {
 FILE_VERSION
 File::getFileVersion(const Key& key) const throw (YAPETException, YAPETInvalidPasswordException) {
     // Expect either a 32bit or 64bit header
-    Record<FileHeader_32>* dec_header_32 = NULL;
-    Record<FileHeader_64>* dec_header_64 = NULL;
+    Record<FileHeader_32>* dec_header_32 = 0;
+    Record<FileHeader_64>* dec_header_64 = 0;
 
     readHeader(key, &dec_header_32, &dec_header_64);
-    assert(dec_header_32 != NULL || dec_header_64 != NULL);
+    assert(dec_header_32 != 0 || dec_header_64 != 0);
 
     FileHeader_32* ptr_dec_header_32 = 
-	(dec_header_32 != NULL) ? static_cast<FileHeader_32*>(*dec_header_32) : NULL;
+	(dec_header_32 != 0) ? static_cast<FileHeader_32*>(*dec_header_32) : 0;
     FileHeader_64* ptr_dec_header_64 = 
-	(dec_header_64 != NULL) ? static_cast<FileHeader_64*>(*dec_header_64) : NULL;
+	(dec_header_64 != 0) ? static_cast<FileHeader_64*>(*dec_header_64) : 0;
 
     FILE_VERSION v;
-    if (ptr_dec_header_32 != NULL) {
+    if (ptr_dec_header_32 != 0) {
 	v = static_cast<FILE_VERSION>(ptr_dec_header_32->version);
     } else {
-	assert(ptr_dec_header_64 != NULL);
+	assert(ptr_dec_header_64 != 0);
 	v = static_cast<FILE_VERSION>(ptr_dec_header_64->version);
     }
 
-    if (dec_header_32 != NULL)
+    if (dec_header_32 != 0)
 	delete dec_header_32;
-    if (dec_header_64 != NULL)
+    if (dec_header_64 != 0)
 	delete dec_header_64;
 
     return v;
@@ -990,7 +982,7 @@ File::operator= (const File & f) throw (YAPETException) {
     fd = dup (f.fd);
 
     if (fd == -1)
-        throw YAPETException (strerror (errno) );
+        throw YAPETException (std::strerror (errno) );
 
     filename = f.filename;
     return *this;
