@@ -1,8 +1,8 @@
 // -*- c++ -*-
 //
-// $Id: key.h 2719 2009-08-20 01:30:25Z rafi $
+// $Id: key.h 5579 2013-11-20 20:54:28Z rafisol $
 //
-// Copyright (C) 2008, 2009  Rafael Ostertag
+// Copyright (C) 2008-2010  Rafael Ostertag
 //
 // This file is part of YAPET.
 //
@@ -31,10 +31,10 @@
 //
 
 #ifndef _KEY_H
-#define _KEY_H
+#define _KEY_H 1
 
 #ifdef HAVE_CONFIG_H
-# include <config.h>
+# include "config.h"
 #endif
 
 #ifdef HAVE_INTTYPES_H
