@@ -1,6 +1,6 @@
-// $Id: partdec.cc 2719 2009-08-20 01:30:25Z rafi $
+// $Id: partdec.cc 5644 2013-11-23 08:36:06Z rafisol $
 //
-// Copyright (C) 2008, 2009  Rafael Ostertag
+// Copyright (C) 2008-2010  Rafael Ostertag
 //
 // This file is part of YAPET.
 //
@@ -28,9 +28,7 @@
 // well as that of the covered work.
 //
 
-#ifdef HAVE_STRING_H
-# include<string.h>
-#endif
+#include <cstring>
 
 #include "partdec.h"
 
@@ -40,7 +38,7 @@
 using namespace YAPET;
 
 PartDec::PartDec() {
-    memset (name, 0, NAME_SIZE);
+    std::memset (name, 0, NAME_SIZE);
 }
 
 PartDec::PartDec (BDBuffer& bd, const Key& key)
@@ -48,7 +46,7 @@ throw (YAPETException) : enc_data (bd) {
     Crypt crypt (key);
     Record<PasswordRecord>* dec_pw_rec = crypt.decrypt<PasswordRecord> (bd);
     PasswordRecord* ptr_dec_pw_rec = *dec_pw_rec;
-    memcpy (name, ptr_dec_pw_rec->name, NAME_SIZE);
+    std::memcpy (name, ptr_dec_pw_rec->name, NAME_SIZE);
     delete dec_pw_rec;
 }
 
@@ -57,17 +55,17 @@ PartDec::PartDec (Record<PasswordRecord>& pr, const Key& key) throw (YAPETExcept
 }
 
 PartDec::PartDec (const PartDec& pd) : enc_data (pd.enc_data) {
-    memcpy (name, pd.name, NAME_SIZE);
+    std::memcpy (name, pd.name, NAME_SIZE);
 }
 
 PartDec::~PartDec() {
-    memset (name, 0, NAME_SIZE);
+    std::memset (name, 0, NAME_SIZE);
 }
 
 void
 PartDec::setRecord (Record<PasswordRecord>& pr, const Key& key) throw (YAPETException) {
     PasswordRecord* ptr_pr = pr;
-    memcpy (name, ptr_pr->name, NAME_SIZE);
+    std::memcpy (name, ptr_pr->name, NAME_SIZE);
     Crypt crypt (key);
     BDBuffer* enc_pr = crypt.encrypt (pr);
     enc_data = *enc_pr;
@@ -78,8 +76,8 @@ const PartDec&
 PartDec::operator= (const PartDec & pd) {
     if (this == &pd) return *this;
 
-    memset (name, 0, NAME_SIZE);
-    memcpy (name, pd.name, NAME_SIZE);
+    std::memset (name, 0, NAME_SIZE);
+    std::memcpy (name, pd.name, NAME_SIZE);
     enc_data = pd.enc_data;
     return *this;
 }
@@ -91,7 +89,17 @@ bool
 PartDec::operator< (const PartDec& pd) const {
     if (this == &pd) return false;
 
-    if (strcmp ( (const char*) name, (const char*) pd.name) < 0)
+    if (std::strcmp ( (const char*) name, (const char*) pd.name) < 0)
+        return true;
+
+    return false;
+}
+
+bool
+PartDec::operator> (const PartDec& pd) const {
+    if (this == &pd) return false;
+
+    if (std::strcmp ( (const char*) name, (const char*) pd.name) > 0)
         return true;
 
     return false;
