@@ -1,8 +1,8 @@
 // -*- c++ -*-
 //
-// $Id: record.h 2826 2009-08-31 17:49:57Z rafi $
+// $Id: record.h 5644 2013-11-23 08:36:06Z rafisol $
 //
-// Copyright (C) 2008, 2009  Rafael Ostertag
+// Copyright (C) 2008-2010  Rafael Ostertag
 //
 // This file is part of YAPET.
 //
@@ -31,25 +31,20 @@
 //
 
 #ifndef _RECORD_H
-#define _RECORD_H
+#define _RECORD_H 1
 
 #ifdef HAVE_CONFIG_H
-# include <config.h>
+# include "config.h"
 #endif
 
 #ifdef HAVE_INTTYPES_H
 # include <inttypes.h>
 #endif
 
-#ifdef HAVE_STDLIB_H
-# include <stdlib.h>
-#endif
+#include <cstdlib>
+#include <cstring>
 
-#ifdef HAVE_STRING_H
-# include <string.h>
-#endif
-
-#include "../intl.h"
+#include "intl.h"
 
 #include "bdbuffer.h"
 #include "yapetexception.h"
@@ -91,9 +86,9 @@ namespace YAPET {
              * struct and sets the \c _size field.
              */
             void alloc_mem() throw (YAPETException) {
-                data = (T*) malloc (sizeof (T) );
+                data = (T*) std::malloc (sizeof (T) );
 
-                if (data == NULL)
+                if (data == 0)
                     throw YAPETException (_ ("Memory exhausted") );
 
                 _size = sizeof (T);
@@ -105,8 +100,8 @@ namespace YAPET {
              * Zero'es the memory out and frees it.
              */
             void free_mem() {
-                memset (data, 0, _size);
-                free (data);
+                std::memset (data, 0, _size);
+                std::free (data);
             }
 
         public:
@@ -121,7 +116,7 @@ namespace YAPET {
              */
             Record<T> (const T& d) throw (YAPETException) {
                 alloc_mem();
-                memcpy (data, &d, sizeof (T) );
+                std::memcpy (data, &d, sizeof (T) );
             }
 
             /**
@@ -136,7 +131,7 @@ namespace YAPET {
 
             Record<T> (const Record<T>& r) throw (YAPETException) {
                 alloc_mem();
-                memcpy (data, r.data, _size);
+                std::memcpy (data, r.data, _size);
             }
 
             virtual ~Record<T>() {
@@ -232,7 +227,7 @@ namespace YAPET {
                 free_mem();
                 // This sets _size member too
                 alloc_mem();
-                memcpy (data, r.data, r._size);
+                std::memcpy (data, r.data, r._size);
                 return *this;
             }
 
@@ -249,7 +244,7 @@ namespace YAPET {
                 free_mem();
                 // This sets _size member too
                 alloc_mem();
-                memcpy (data, &r, _size);
+                std::memcpy (data, &r, _size);
                 return *this;
             }
 
@@ -266,7 +261,7 @@ namespace YAPET {
                 free_mem();
                 // This sets _size member too
                 alloc_mem();
-                memcpy (data, r, _size);
+                std::memcpy (data, r, _size);
                 return *this;
             }
 
@@ -294,7 +289,7 @@ namespace YAPET {
                 free_mem();
                 // This sets _size member too
                 alloc_mem();
-                memcpy (data, bdb(), _size);
+                std::memcpy (data, bdb(), _size);
                 return *this;
             }
     };
