@@ -1,8 +1,8 @@
 // -*- c++ -*-
 //
-// $Id: structs.h 2827 2009-08-31 18:01:41Z rafi $
+// $Id: structs.h 5623 2013-11-21 14:36:29Z rafisol $
 //
-// Copyright (C) 2008, 2009  Rafael Ostertag
+// Copyright (C) 2008-2010  Rafael Ostertag
 //
 // This file is part of YAPET.
 //
@@ -31,10 +31,10 @@
 //
 
 #ifndef _STRUCTS_H
-#define _STRUCTS_H
+#define _STRUCTS_H 1
 
 #ifdef HAVE_CONFIG_H
-# include <config.h>
+# include "config.h"
 #endif
 
 #ifdef HAVE_INTTYPES_H
@@ -45,9 +45,7 @@
 # include <stdint.h>
 #endif
 
-#ifdef HAVE_SYS_TYPES_H
-# include <sys/types.h>
-#endif
+#include <sys/types.h>
 
 namespace YAPET {
 
