@@ -1,8 +1,8 @@
 // -*- c++ -*-
 //
-// $Id: yapetexception.h 2840 2009-09-01 05:21:41Z rafi $
+// $Id: yapetexception.h 5644 2013-11-23 08:36:06Z rafisol $
 //
-// Copyright (C) 2008, 2009  Rafael Ostertag
+// Copyright (C) 2008-2010  Rafael Ostertag
 //
 // This file is part of YAPET.
 //
@@ -31,36 +31,32 @@
 //
 
 #ifndef _YAPETEXCEPTION_H
-#define _YAPETEXCEPTION_H
+#define _YAPETEXCEPTION_H 1
 
 #ifdef HAVE_CONFIG_H
-# include <config.h>
+# include "config.h"
 #endif
 
-#ifdef HAVE_EXCEPTION
-# include <exception>
-#endif
+#include <exception>
+#include <string>
 
-#ifdef HAVE_STRING
-# include <string>
-#endif
-
-#include "../intl.h"
+#include "intl.h"
 
 namespace YAPET {
 
     /**
      * New in version 0.6
      *
-     * Since version 0.6 we provide an optional error specification. It is
-     * entirely optional to use it, but at the time this writing, the
-     * YAPET::File class uses it to determine whether or not retrying to
-     * decrypt the using a different structure (FileHeader_32 or FileHeader_64)
+     * Since version 0.6 we provide an optional error
+     * specification. It is entirely optional to use it, but at the
+     * time of this writing, the YAPET::File class uses it to
+     * determine whether or not retrying to decrypt the using a
+     * different structure (FileHeader_32 or FileHeader_64)
      */
     enum EXNUM {
 	BDBUFFER_TOO_SMALL = 1,
 	BDBUFFER_TOO_BIG = 2,
-	NULLPOINTER = 3,
+	ZEROPOINTER = 3,
 	NOTUSED = 255
     };
 
