@@ -1,6 +1,6 @@
-// $Id: csvimport.cc 2719 2009-08-20 01:30:25Z rafi $
+// $Id: csvimport.cc 5819 2014-01-01 09:14:13Z rafisol $
 //
-// Copyright (C) 2009  Rafael Ostertag
+// Copyright (C) 2009-2010  Rafael Ostertag
 //
 // This file is part of YAPET.
 //
@@ -29,28 +29,15 @@
 //
 
 #ifdef HAVE_CONFIG_H
-# include <config.h>
+# include "config.h"
 #endif
 
-#ifdef HAVE_UNISTD_H
-# include <unistd.h>
-#endif
+#include <unistd.h>
 
-#ifdef HAVE_STRING_H
-# include <string.h>
-#endif
-
-#ifdef HAVE_STDIO_H
-# include <stdio.h>
-#endif
-
-#ifdef HAVE_IOSTREAM
-# include <iostream>
-#endif
-
-#ifdef HAVE_FSTREAM
-# include <fstream>
-#endif
+#include <cstring>
+#include <cstdio>
+#include <iostream>
+#include <fstream>
 
 #include "csvimport.h"
 #include <structs.h>
@@ -171,8 +158,27 @@ CSVImport::import (const char* pw) throw (std::exception) {
     // The iterator for scanning the line character by character
     std::string::size_type it = 0;
 
-    while (csvfile.getline (line, max_len) ) {
+    bool failmode=false;
+    while (!csvfile.getline (line, max_len).eof() ) {
+	if (csvfile.fail()) {
+	    csvfile.clear();
+	    failmode=true;
+	    continue;
+	}
+
+	if (failmode) {
+	    // now we read an entire line while in failmode, so reset,
+	    // increment line counter, and skip line. This is done so
+	    // that the line counter keeps accurate.
+	    failmode=false;
+	    lineno++;
+	    logError(lineno, "Failed reading line (line too long?)");
+	    continue;
+	}
+
+	// leave this here.
         lineno++;
+
         std::string l (line);
         // integer pointing to the last delimiter found
         std::string::size_type last_sep = 0;
