@@ -1,6 +1,6 @@
-// $Id: main.cc 2719 2009-08-20 01:30:25Z rafi $
+// $Id: main.cc 5906 2014-01-26 12:44:06Z rafisol $
 //
-// Copyright (C) 2009  Rafael Ostertag
+// Copyright (C) 2009-2010  Rafael Ostertag
 //
 // This file is part of YAPET.
 //
@@ -29,46 +29,28 @@
 //
 
 #ifdef HAVE_CONFIG_H
-# include <config.h>
-#endif
-
-#ifdef HAVE_ERRNO_H
-# include <errno.h>
-#endif
-
-#ifdef HAVE_STDIO_H
-# include <stdio.h>
+# include "config.h"
 #endif
 
 #ifdef HAVE_GETOPT_H
 # include <getopt.h>
 #endif
 
-#ifdef HAVE_UNISTD_H
-# include <unistd.h>
-#endif
-
-#ifdef HAVE_STRING_H
-# include <string.h>
-#endif
+#include <unistd.h>
+#include <libgen.h>
 
 #ifdef HAVE_TERMIOS_H
 # include <termios.h>
 #endif
 
-#ifdef HAVE_STRING
-# include <string>
-#endif
+#include <cerrno>
+#include <cstdio>
+#include <cstring>
+#include <string>
+#include <iostream>
+#include <stdexcept>
 
-#ifdef HAVE_IOSTREAM
-# include <iostream>
-#endif
-
-#ifdef HAVE_STDEXCEPT
-# include <stdexcept>
-#endif
-
-#include <consts.h>
+#include "consts.h"
 #include "csvimport.h"
 
 #if defined(HAVE_TERMIOS_H) && defined (HAVE_TCSETATTR) && defined (HAVE_TCGETATTR)
@@ -102,7 +84,7 @@ enum {
     MAX_FILEPATH = 1024
 };
 
-const char COPYRIGHT[] = "\nCopyright (C) 2009  Rafael Ostertag\n"  \
+const char COPYRIGHT[] = "\nCopyright (C) 2009-2011, 2013, 2014  Rafael Ostertag\n"  \
                          "\n"                                \
                          "csv2yapet is part of YAPET.\n"                 \
                          "\n"                                \
@@ -129,13 +111,13 @@ void disable_echo() {
     int err = tcgetattr (STDIN_FILENO, &ctios);
 
     if (err < 0)
-        throw std::runtime_error (strerror (errno) );
+        throw std::runtime_error (std::strerror (errno) );
 
     ctios.c_lflag &= ~ECHO;
     err = tcsetattr (STDIN_FILENO, TCSANOW, &ctios);
 
     if (err < 0)
-        throw std::runtime_error (strerror (errno) );
+        throw std::runtime_error (std::strerror (errno) );
 
 #endif
 }
@@ -149,19 +131,18 @@ void enable_echo() {
     int err = tcgetattr (STDIN_FILENO, &ctios);
 
     if (err < 0)
-        throw std::runtime_error (strerror (errno) );
+        throw std::runtime_error (std::strerror (errno) );
 
     ctios.c_lflag |= ECHO;
     err = tcsetattr (STDIN_FILENO, TCSANOW, &ctios);
 
     if (err < 0)
-        throw std::runtime_error (strerror (errno) );
+        throw std::runtime_error (std::strerror (errno) );
 
 #endif
 }
 
 void show_version() {
-    std::cout << std::endl;
     std::cout << "csv2yapet is part of ";
     std::cout << PACKAGE_STRING << std::endl;
 }
@@ -172,41 +153,39 @@ void show_copyright() {
 
 void show_help (char* prgname) {
     std::cout << std::endl;
-    std::cout << prgname
+    std::cout << basename(prgname)
               << " [-h] [-p <password>] [-q] [-s <char>] [-V] <src> <dst>"
               << std::endl
               << std::endl;
-    std::cout << "-c, --copyright\tshow copyright information"
+    std::cout << "-c\tshow copyright information"
               << std::endl
               << std::endl;
-    std::cout << "-h, --help\tshow this help text"
+    std::cout << "-h\tshow this help text"
               << std::endl
               << std::endl;
-    std::cout << "-p, --password\tuse <password> as the password for the file created"
+    std::cout << "-p\tuse <password> as the master password for the YAPET file."
               << std::endl
-              << "\t\tby the convert."
-              << std::endl
-              << "\t\tThe use of this option is discouraged."
+              << "\tThe use of this option is discouraged."
               << std::endl
               << std::endl;
-    std::cout << "-q, --quiet\toperate quietly"
+    std::cout << "-q\toperate quietly"
               << std::endl
               << std::endl;
-    std::cout << "-s, --separator\tuse <char> as field separator."
+    std::cout << "-s\tuse <char> as field separator."
               << std::endl
-              << "\t\tDefault: ,"
+              << "\tDefault: ,"
               << std::endl
               << std::endl;
-    std::cout << "-V, --version\tshow the version of csv2yapet"
+    std::cout << "-V\tshow the version of csv2yapet"
               << std::endl
               << std::endl;
-    std::cout << "<src>\t\tthe source csv file"
+    std::cout << "<src>\tthe source csv file"
               << std::endl
               << std::endl;
-    std::cout << "<dst>\t\tthe output file"
+    std::cout << "<dst>\tthe output file"
               << std::endl
               << std::endl;
-    std::cout << "csv2yapet converts csv text files to files readable by YAPET."
+    std::cout << "csv2yapet converts CSV text files to YAPET files."
               << std::endl
               << std::endl;
 }
@@ -218,26 +197,12 @@ int main (int argc, char** argv) {
     char separator = ',';
     std::string srcfile;
     std::string dstfile;
-    int c;
-#ifdef HAVE_GETOPT_LONG
-    struct option long_options[] = {
-        { (char*) "copyright", no_argument, NULL, 'c'},
-        { (char*) "help", no_argument, NULL, 'h'},
-        { (char*) "password", required_argument, NULL, 'p'},
-        { (char*) "quiet", no_argument, NULL, 'q'},
-        { (char*) "separator", required_argument, NULL, 's'},
-        { (char*) "version", no_argument, NULL, 'V'},
-        {NULL, 0, NULL, 0}
-    };
 
-    while ( (c = getopt_long (argc, argv, ":chp:qs:V", long_options, NULL) ) != -1) {
-#else // HAVE_GETOPT_LONG
+    int c;
     extern char *optarg;
     extern int optopt, optind;
 
-    while ( (c = getopt (argc, argv, ":c(copyright)h(help)p:(password)q(quiet)s:(separator)V(version)") ) != -1) {
-#endif // HAVE_GETOPT_LONG
-
+    while ( (c = getopt (argc, argv, ":chp:qs:V") ) != -1) {
         switch (c) {
             case 'c':
                 show_copyright();
@@ -247,13 +212,14 @@ int main (int argc, char** argv) {
                 return 0;
             case 'p':
                 strncpy (passwd, optarg, MAX_PASSWD);
+		passwd[MAX_PASSWD-1] = 0;
                 cmdline_pw = true;
                 break;
             case 'q':
                 quiet = true;
                 break;
             case 's':
-                sscanf (optarg, "%c", &separator);
+		separator=optarg[0];
                 break;
             case 'V':
                 show_version();
@@ -270,11 +236,8 @@ int main (int argc, char** argv) {
     }
 
     if (optind < argc && (argc - optind) == 2) {
-        char tmp[MAX_FILEPATH];
-        strncpy (tmp, argv[optind], MAX_FILEPATH);
-        srcfile = tmp;
-        strncpy (tmp, argv[++optind], MAX_FILEPATH);
-        dstfile = tmp;
+        srcfile = argv[optind];
+        dstfile = argv[++optind];
     } else {
         std::cerr << "Missing argument." << std::endl;
 
@@ -284,11 +247,11 @@ int main (int argc, char** argv) {
         return ERR_CMDLINE;
     }
 
-    if ( dstfile.find (YAPET::CONSTS::Consts::getDefaultSuffix(),
+    if ( dstfile.find (YAPET::Consts::default_suffix,
                        dstfile.length() -
-                       YAPET::CONSTS::Consts::getDefaultSuffix().length() )
+                       YAPET::Consts::default_suffix.length() )
             == std::string::npos )
-        dstfile += YAPET::CONSTS::Consts::getDefaultSuffix();
+        dstfile += YAPET::Consts::default_suffix;
 
     if (access (dstfile.c_str(), F_OK) == 0) {
         std::cerr << dstfile << " already exists. Aborting." << std::endl;
@@ -297,7 +260,7 @@ int main (int argc, char** argv) {
 
     try {
         // We read the password from stdin only if the user did not provide the
-        // -s switch.
+        // -p switch.
         if (!cmdline_pw) {
             std::cout << "Please enter the password for " << dstfile << ": ";
             std::cout.flush();
