@@ -1,18 +1,28 @@
-// $Id: enc.cc 2845 2009-09-01 09:33:31Z rafi $
+// $Id: enc.cc 5646 2013-11-23 08:38:40Z rafisol $
+
+#ifdef HAVE_CONFIG_H
+# include "config.h"
+#endif
 
 #include <typeinfo>
 #include <iostream>
-#include <sys/types.h>
-#include <sys/stat.h>
-#include <fcntl.h>
+
 #include <unistd.h>
 
+#include <sys/types.h>
 
-#include <crypt.h>
-#include <structs.h>
-#include <record.h>
-#include <bdbuffer.h>
-#include <key.h>
+#include <sys/stat.h>
+
+#ifdef HAVE_FCNTL_H
+# include <fcntl.h>
+#endif
+
+
+#include "crypt.h"
+#include "structs.h"
+#include "record.h"
+#include "bdbuffer.h"
+#include "key.h"
 
 #define CONTROL_STR "ABCDEFGHIJKLMNOPQRSTUVW"
 
@@ -28,7 +38,7 @@ int main (int, char**) {
         YAPET::Crypt crypt (key);
         YAPET::FileHeader_64 header;
         header.version = YAPET::VERSION_2;
-        memcpy (header.control, CONTROL_STR, YAPET::HEADER_CONTROL_SIZE);
+        std::memcpy (header.control, CONTROL_STR, YAPET::HEADER_CONTROL_SIZE);
         YAPET::Record<YAPET::FileHeader_64> record (header);
         YAPET::BDBuffer* data = crypt.encrypt (record);
         YAPET::Record<YAPET::FileHeader_64>* dec_header;
@@ -36,7 +46,7 @@ int main (int, char**) {
         delete data;
         YAPET::FileHeader_64* fh_ptr (*dec_header);
 
-        if (memcmp (fh_ptr->control, CONTROL_STR, YAPET::HEADER_CONTROL_SIZE) != 0)
+        if (std::memcmp (fh_ptr->control, CONTROL_STR, YAPET::HEADER_CONTROL_SIZE) != 0)
             return 1;
 
         delete dec_header;
