@@ -1,22 +1,31 @@
-// $Id: import6.cc 2845 2009-09-01 09:33:31Z rafi $
+// $Id: import6.cc 5623 2013-11-21 14:36:29Z rafisol $
 // Checks whether or not the import of import5 worked.
 // Relies on test4.csv
 
+#ifdef HAVE_CONFIG_H
+# include "config.h"
+#endif
+
 #include <typeinfo>
-
-#include <string.h>
-#include <sys/types.h>
-#include <sys/stat.h>
-#include <fcntl.h>
-#include <unistd.h>
 #include <iostream>
+#include <cstring>
 
-#include <key.h>
-#include <crypt.h>
-#include <structs.h>
-#include <record.h>
-#include <partdec.h>
-#include <file.h>
+#include <unistd.h>
+
+#include <sys/types.h>
+
+#include <sys/stat.h>
+
+#ifdef HAVE_FCNTL_H
+# include <fcntl.h>
+#endif
+
+#include "key.h"
+#include "crypt.h"
+#include "structs.h"
+#include "record.h"
+#include "partdec.h"
+#include "file.h"
 
 #include "tests.h"
 
