@@ -1,4 +1,4 @@
-// $Id: import9.cc 2845 2009-09-01 09:33:31Z rafi $
+// $Id: import9.cc 5623 2013-11-21 14:36:29Z rafisol $
 //
 // Tests whether or not import works with double quoted values and escaped
 // double quotes.
@@ -6,19 +6,23 @@
 // Relies on test6.csv
 
 #ifdef HAVE_CONFIG_H
-# include <config.h>
+# include "config.h"
 #endif
 
-#ifdef HAVE_IOSTREAM
-# include <iostream>
-#endif
-#include <sys/types.h>
-#include <sys/stat.h>
-#include <fcntl.h>
-#include <unistd.h>
+#include <iostream>
 #include <typeinfo>
 
-#include <csvimport.h>
+#include <unistd.h>
+
+#include <sys/types.h>
+
+#include <sys/stat.h>
+
+#ifdef HAVE_FCNTL_H
+# include <fcntl.h>
+#endif
+
+#include "csvimport.h"
 
 #include "testpaths.h"
 
