@@ -1,39 +1,24 @@
-// $Id: rng1.cc 2863 2009-09-01 15:25:52Z rafi $
+// $Id: rng1.cc 5623 2013-11-21 14:36:29Z rafisol $
 // Simple tests for yapet/pwgen/rng.*
 
 #ifdef HAVE_CONFIG_H
-# include <config.h>
+# include "config.h"
 #endif
 
-#ifdef HAVE_IOSTREAM
-# include <iostream>
-#endif
+#include <iostream>
+#include <cstring>
+#include <cstdlib>
+#include <typeinfo>
 
-#ifdef HAVE_STRING_H
-# include <string.h>
-#endif
+#include <unistd.h>
 
-#ifdef HAVE_UNISTD_H
-# include <unistd.h>
-#endif
-
-#ifdef HAVE_STDLIB_H
-# include <stdlib.h>
-#endif
-
-#ifdef HAVE_SYS_TYPES_H
-# include <sys/types.h>
-#endif
-#ifdef HAVE_SYS_STAT_H
-# include <sys/stat.h>
-#endif
+#include <sys/types.h>
+#include <sys/stat.h>
 #ifdef HAVE_FCNTL_H
 # include <fcntl.h>
 #endif
 
-#include <typeinfo>
-
-#include <rng.h>
+#include "rng.h"
 
 #include "testpaths.h"
 
@@ -86,7 +71,7 @@ int main (int, char**) {
             std::cout << devrandom (MYCEILING) << " ";
 	}
 # else
-	std::cout << " ==> /dev/random will only be tested if explicitely requested.";
+	std::cout << " ==> /dev/random will only be tested if explicitly requested.";
 # endif
         std::cout << std::endl;
 #endif
