@@ -1,6 +1,6 @@
-// $Id: consts.cc 2719 2009-08-20 01:30:25Z rafi $
+// $Id: consts.cc 5640 2013-11-22 17:00:10Z rafisol $
 //
-// Copyright (C) 2009  Rafael Ostertag
+// Copyright (C) 2009-2010  Rafael Ostertag
 //
 // This file is part of YAPET.
 //
@@ -20,23 +20,10 @@
 
 #include "consts.h"
 
-using namespace YAPET::CONSTS;
+using namespace YAPET;
 
-const std::string Consts::default_suffix (".pet");
-const std::string Consts::default_rcfilename (".yapet");
-const size_t Consts::max_pwlen(256);
-
-const std::string&
-Consts::getDefaultSuffix() {
-    return default_suffix;
-}
-
-const std::string&
-Consts::getDefaultRCFilename() {
-    return default_rcfilename;
-}
-
-size_t
-Consts::getMaxPWLength() {
-    return max_pwlen;
-}
+const std::string Consts::default_suffix(".pet");
+const std::string Consts::default_rcfilename(".yapet");
+const bool Consts::def_filesecurity(true);
+const bool Consts::def_allow_lock_quit(true);
+const YAPET::PWGEN::RNGENGINE Consts::def_pwgen_rng(YAPET::PWGEN::AUTO);
